## Changelog

### 0.1.3 / 2016-07-11
- [#8](https://github.com/uphold/aiopype/pull/8) Fix AsyncProtocol termination condition (@jAlpedrinha)

### 0.1.2 / 2016-07-06
- [#6](https://github.com/uphold/aiopype/pull/6) Handle exceptions from async protocol listener (@jAlpedrinha)

### 0.1.1 / 2016-07-05
- [#4](https://github.com/uphold/aiopype/pull/4) Avoid failure on pusherclient disconnection (@jAlpedrinha)

### 0.1.0 / 2016-07-05
- [#1](https://github.com/uphold/aiopype/pull/1) Add flow manager and processors (@jAlpedrinha)